@@ -20,9 +20,6 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-from __future__ import print_function
-from __future__ import division
-
 import _tskit
 FORWARD = _tskit.FORWARD
 REVERSE = _tskit.REVERSE
